==> sgq-business-0.4-sources.jar: com/herbocailleau/sgq/entities/ProductionDAOAbstract.java <==
package com.herbocailleau.sgq.entities;

import com.herbocailleau.sgq.SGQDAOHelper.SGQEntityEnum;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.persistence.TopiaDAOImpl;
import org.nuiton.topia.persistence.TopiaEntity;

public abstract class ProductionDAOAbstract<E extends Production> extends TopiaDAOImpl<E> {

    @Override
    public Class<E> getEntityClass() {
        return (Class<E>)Production.class;
    }

    @Override
    public SGQEntityEnum getTopiaEntityEnum() {
        return SGQEntityEnum.Production;
    }

    public E findByDate(Date v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_DATE, v);
        return result;
    }

    public List<E> findAllByDate(Date v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_DATE, v);
        return result;
    }

    public E findByQuantity(double v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_QUANTITY, v);
        return result;
    }

    public List<E> findAllByQuantity(double v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_QUANTITY, v);
        return result;
    }

    public E findByPresentation(Presentation v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_PRESENTATION, v);
        return result;
    }

    public List<E> findAllByPresentation(Presentation v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_PRESENTATION, v);
        return result;
    }

    public E findByDestination(Zone v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_DESTINATION, v);
        return result;
    }

    public List<E> findAllByDestination(Zone v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_DESTINATION, v);
        return result;
    }

    public E findBySource(Zone v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_SOURCE, v);
        return result;
    }

    public List<E> findAllBySource(Zone v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_SOURCE, v);
        return result;
    }

    @Override
    public <U extends TopiaEntity> List<U> findUsages(Class<U> type, E entity) throws TopiaException {
        return new ArrayList<U>();
    }

    @Override
    public Map<Class<? extends TopiaEntity>, List<? extends TopiaEntity>> findAllUsages(E entity) throws TopiaException {
        return new HashMap<Class<? extends TopiaEntity>, List<? extends TopiaEntity>>();
    }

} //ProductionDAOAbstract<E extends Production>

==> sgq-business-1.1.5-sources.jar: com/herbocailleau/sgq/entities/ProductionDAOAbstract.java <==
package com.herbocailleau.sgq.entities;

import com.herbocailleau.sgq.SGQDAOHelper.SGQEntityEnum;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.persistence.TopiaDAOImpl;
import org.nuiton.topia.persistence.TopiaEntity;

public abstract class ProductionDAOAbstract<E extends Production> extends TopiaDAOImpl<E> {

    @Override
    public Class<E> getEntityClass() {
        return (Class<E>)Production.class;
    }

    @Override
    public SGQEntityEnum getTopiaEntityEnum() {
        return SGQEntityEnum.Production;
    }

    public E findByDate(Date v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_DATE, v);
        return result;
    }

    public List<E> findAllByDate(Date v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_DATE, v);
        return result;
    }

    public E findByQuantity(double v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_QUANTITY, v);
        return result;
    }

    public List<E> findAllByQuantity(double v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_QUANTITY, v);
        return result;
    }

    public E findByPresentation(Presentation v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_PRESENTATION, v);
        return result;
    }

    public List<E> findAllByPresentation(Presentation v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_PRESENTATION, v);
        return result;
    }

    public E findByDestination(Zone v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_DESTINATION, v);
        return result;
    }

    public List<E> findAllByDestination(Zone v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_DESTINATION, v);
        return result;
    }

    public E findBySource(Zone v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_SOURCE, v);
        return result;
    }

    public List<E> findAllBySource(Zone v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_SOURCE, v);
        return result;
    }

    public E findByCorrection(Presentation v) throws TopiaException {
        E result = findByProperty(Production.PROPERTY_CORRECTION, v);
        return result;
    }

    public List<E> findAllByCorrection(Presentation v) throws TopiaException {
        List<E> result = findAllByProperty(Production.PROPERTY_CORRECTION, v);
        return result;
    }

    @Override
    public <U extends TopiaEntity> List<U> findUsages(Class<U> type, E entity) throws TopiaException {
        return new ArrayList<U>();
    }

    @Override
    public Map<Class<? extends TopiaEntity>, List<? extends TopiaEntity>> findAllUsages(E entity) throws TopiaException {
        return new HashMap<Class<? extends TopiaEntity>, List<? extends TopiaEntity>>();
    }

} //ProductionDAOAbstract<E extends Production>
